@@ -70,6 +70,8 @@ int main(int argc, char *argv[])
 		family = NFPROTO_IPV4;
 	else if (strcmp(argv[1], "ip6") == 0)
 		family = NFPROTO_IPV6;
+	else if (strcmp(argv[1], "inet") == 0)
+		family = NFPROTO_INET;
 	else if (strcmp(argv[1], "bridge") == 0)
 		family = NFPROTO_BRIDGE;
 	else if (strcmp(argv[1], "arp") == 0)
@@ -77,7 +79,7 @@ int main(int argc, char *argv[])
 	else if (strcmp(argv[1], "unspec") == 0)
 		family = NFPROTO_UNSPEC;
 	else {
-		fprintf(stderr, "Unknown family: ip, ip6, bridge, arp, unspec\n");
+		fprintf(stderr, "Unknown family: ip, ip6, inet, bridge, arp, unspec\n");
 		exit(EXIT_FAILURE);
 	}
 
