@@ -35,13 +35,13 @@ nftnl_expr_fib_set(struct nftnl_expr *e, uint16_t result,
 
 	switch (result) {
 	case NFTNL_EXPR_FIB_RESULT:
-		fib->result = *((uint32_t *)data);
+		memcpy(&fib->result, data, sizeof(fib->result));
 		break;
 	case NFTNL_EXPR_FIB_DREG:
-		fib->dreg = *((uint32_t *)data);
+		memcpy(&fib->dreg, data, sizeof(fib->dreg));
 		break;
 	case NFTNL_EXPR_FIB_FLAGS:
-		fib->flags = *((uint32_t *)data);
+		memcpy(&fib->flags, data, sizeof(fib->flags));
 		break;
 	default:
 		return -1;
@@ -128,31 +128,6 @@ nftnl_expr_fib_parse(struct nftnl_expr *e, struct nlattr *attr)
 	return ret;
 }
 
-static int nftnl_expr_fib_json_parse(struct nftnl_expr *e, json_t *root,
-				      struct nftnl_parse_err *err)
-{
-#ifdef JSON_PARSING
-	uint32_t result, flags, dreg;
-
-	if (nftnl_jansson_parse_reg(root, "result", NFTNL_TYPE_U32,
-				    &result, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_FIB_RESULT, result);
-
-	if (nftnl_jansson_parse_reg(root, "dreg", NFTNL_TYPE_U32,
-				    &dreg, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_FIB_DREG, dreg);
-
-	if (nftnl_jansson_parse_val(root, "flags", NFTNL_TYPE_U32,
-				    &flags, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_FIB_FLAGS, flags);
-
-	return 0;
-#else
-	errno = EOPNOTSUPP;
-	return -1;
-#endif
-}
-
 static const char *fib_type[NFT_FIB_RESULT_MAX + 1] = {
 	[NFT_FIB_RESULT_OIF] = "oif",
 	[NFT_FIB_RESULT_OIFNAME] = "oifname",
@@ -168,13 +143,13 @@ static const char *fib_type_str(enum nft_fib_result r)
 }
 
 static int
-nftnl_expr_fib_snprintf_default(char *buf, size_t size,
-				const struct nftnl_expr *e)
+nftnl_expr_fib_snprintf(char *buf, size_t remain,
+			 uint32_t printflags, const struct nftnl_expr *e)
 {
 	struct nftnl_expr_fib *fib = nftnl_expr_data(e);
-	int remain = size, offset = 0, ret, i;
 	uint32_t flags = fib->flags & ~NFTA_FIB_F_PRESENT;
 	uint32_t present_flag = fib->flags & NFTA_FIB_F_PRESENT;
+	int offset = 0, ret, i;
 	static const struct {
 		int bit;
 		const char *name;
@@ -215,65 +190,13 @@ nftnl_expr_fib_snprintf_default(char *buf, size_t size,
 	return offset;
 }
 
-static int nftnl_expr_fib_export(char *buf, size_t size,
-				  const struct nftnl_expr *e, int type)
-{
-	struct nftnl_expr_fib *fib = nftnl_expr_data(e);
-
-	NFTNL_BUF_INIT(b, buf, size);
-
-	if (e->flags & (1 << NFTNL_EXPR_FIB_RESULT))
-		nftnl_buf_u32(&b, type, fib->result, OP);
-	if (e->flags & (1 << NFTNL_EXPR_FIB_DREG))
-		nftnl_buf_u32(&b, type, fib->dreg, DREG);
-	if (e->flags & (1 << NFTNL_EXPR_FIB_FLAGS))
-		nftnl_buf_u32(&b, type, fib->flags, FLAGS);
-
-	return nftnl_buf_done(&b);
-}
-
-static int
-nftnl_expr_fib_snprintf(char *buf, size_t len, uint32_t type,
-			 uint32_t flags, const struct nftnl_expr *e)
-{
-	switch (type) {
-	case NFTNL_OUTPUT_DEFAULT:
-		return nftnl_expr_fib_snprintf_default(buf, len, e);
-	case NFTNL_OUTPUT_XML:
-	case NFTNL_OUTPUT_JSON:
-		return nftnl_expr_fib_export(buf, len, e, type);
-	default:
-		break;
-	}
-	return -1;
-}
-
-static bool nftnl_expr_fib_cmp(const struct nftnl_expr *e1,
-				const struct nftnl_expr *e2)
-{
-       struct nftnl_expr_fib *h1 = nftnl_expr_data(e1);
-       struct nftnl_expr_fib *h2 = nftnl_expr_data(e2);
-       bool eq = true;
-
-       if (e1->flags & (1 << NFTNL_EXPR_FIB_RESULT))
-               eq &= (h1->result == h2->result);
-       if (e1->flags & (1 << NFTNL_EXPR_FIB_DREG))
-               eq &= (h1->dreg == h2->dreg);
-       if (e1->flags & (1 << NFTNL_EXPR_FIB_FLAGS))
-               eq &= (h1->flags == h2->flags);
-
-       return eq;
-}
-
 struct expr_ops expr_ops_fib = {
 	.name		= "fib",
 	.alloc_len	= sizeof(struct nftnl_expr_fib),
 	.max_attr	= NFTA_FIB_MAX,
-	.cmp		= nftnl_expr_fib_cmp,
 	.set		= nftnl_expr_fib_set,
 	.get		= nftnl_expr_fib_get,
 	.parse		= nftnl_expr_fib_parse,
 	.build		= nftnl_expr_fib_build,
 	.snprintf	= nftnl_expr_fib_snprintf,
-	.json_parse	= nftnl_expr_fib_json_parse,
 };
